summaryrefslogtreecommitdiffstats
path: root/test/mingw.py
diff options
context:
space:
mode:
authorSteven Knight <knight@baldmt.com>2005-09-26 04:19:32 (GMT)
committerSteven Knight <knight@baldmt.com>2005-09-26 04:19:32 (GMT)
commit0d2cb0988d25be7125e27d4a7fa965c8ba04c585 (patch)
tree7c7b7025cd6671f75c9f4f26cfbdd8002d902cca /test/mingw.py
parent1c3439fc04d37b0037faf1ed84ae57698c4c58ba (diff)
downloadSCons-0d2cb0988d25be7125e27d4a7fa965c8ba04c585.zip
SCons-0d2cb0988d25be7125e27d4a7fa965c8ba04c585.tar.gz
SCons-0d2cb0988d25be7125e27d4a7fa965c8ba04c585.tar.bz2
Explicit "skipping test" messages for a few straggling tests.
Diffstat (limited to 'test/mingw.py')
-rw-r--r--test/mingw.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/mingw.py b/test/mingw.py
index d2039b5..ba6add8 100644
--- a/test/mingw.py
+++ b/test/mingw.py
@@ -43,7 +43,7 @@ if sys.platform != 'win32':
msg = "Skipping mingw test on non-Windows platform '%s'\n" % sys.platform
test.skip_test(msg)
# This test requires MingW to be installed:
test.write('SConstruct',"""
from SCons.Tool.mingw import exists
import sys
@@ -55,7 +55,7 @@ sys.exit(0)
test.run()
if string.find(test.stdout(), 'mingw exists') == -1:
- test.no_result()
+ test.skip_test("No MinGW on this system, skipping test.\n")
test.subdir('header')
@@ -43,7 +43,7 @@ if sys.platform != 'win32':
msg = "Skipping mingw test on non-Windows platform '%s'\n" % sys.platform
test.skip_test(msg)
-# This test requires MingW to be installed:
+# This test requires MinGW to be installed:
test.write('SConstruct',"""
from SCons.Tool.mingw import exists